import { defineStore } from 'pinia'
import { useDialogueStore } from '@/store'
import lodash from 'lodash'

import {ref} from 'vue'
import {createGlobalState,useStorage} from '@vueuse/core'
import {uniStorage} from "@/utils/uniStorage.js"
import {departmentV2TreeMy,departmentV2AllPosition,groupCreateDept,departmentV2TreeAll,userV2List} from '@/api/deps/index.js'

export const useGroupTypeStore = createGlobalState(() => {
  const groupName = ref('')
  const groupActiveIndex = ref(-1) // 当前激活的分组索引
  const depTreeMyList = ref([])
  const postTreeList = ref([])
  const crumbs = ref([])
  const crumbsIndex = ref(0)
  const depCheckedKeys = ref([]) // 选中的部门keys
  const groupAdmins = ref([]) // 选中的管理员
  const membersCheckedKeys = ref([]) // 选中的人员keys
  const allChooseMembers = ref([])

  const getDepsTreeMy= async()=>{
    const res = await departmentV2TreeAll()
    if(res.status===0){
      depTreeMyList.value = res.data.nodes
    }
  }

  const getPositionsTree= async()=>{
    const res = await departmentV2AllPosition()
    if(res.status===0){
      postTreeList.value = res.data.nodes
    }
  }

  const getDepMembers= async(param)=>{
    const res = await userV2List(param)
    return res;
  }

  const resetGroupInfo = () => {
    groupName.value = '';
    groupActiveIndex.value = -1;
    depTreeMyList.value = [];
    postTreeList.value = [];
    crumbs.value = [];
    crumbsIndex.value = 0
    depCheckedKeys.value = []
    groupAdmins.value = []
  }

  const createDepGroup = async (param) => {
    const res = await groupCreateDept({
      name:groupName.value,
      deptInfos:depCheckedKeys.value.map(v=>{
        return {
          dept_id:v.ID,
          dept_name:v.name
        }
      }),
      positionInfos:groupAdmins.value.map(v=>{
        return {
          position_id:v.ID,
          position_name:v.name
        }
      })
    })
    return res;
  }


  return {
    groupName,
    groupActiveIndex,
    depTreeMyList,
    postTreeList,
    getDepsTreeMy,
    getPositionsTree,
    crumbs,
    crumbsIndex,
    depCheckedKeys,
    groupAdmins,
    resetGroupInfo,
    createDepGroup,
    getDepMembers,
    membersCheckedKeys,
    allChooseMembers,
  }
})
